import { IMessagesRepository } from '@modules/messages/repositories/IMessagesRepository';
import { AppError } from '@shared/error/AppError';
import 'reflect-metadata';
import { inject, injectable } from 'tsyringe';

interface IRequest {
    message: string,
    forum_id: string
}

@injectable()
class CreateMessageUseCase {
    constructor(
        @inject('MessageRepository')
        private messagesRepository: IMessagesRepository
    ) { }

    async execute({ message, forum_id }: IRequest) {
        const forumDoesntExist = await this.messagesRepository.findByForum(forum_id)
        if (!forumDoesntExist) {
            throw new AppError('Forum doesnt exists', 404);
        }

        const messagem = await this.messagesRepository.create({
            message,
            forum_id
        })

        return messagem
    }
}

export { CreateMessageUseCase }